@@ -199,9 +199,7 @@ class DBConnect:
         # 去重查询
         try:
             query_res = self.mongo_collection.distinct(find_str)
-            if query_res:
-                return int(query_res[0])
-            return 0
+            return len(query_res)
         except Exception as err:
             handle_abnormal(
                 message='MongoDB(组件)出现查询错误',
